<!--
  ~ Copyright (c) 2006, WSO2 Inc. (http://www.wso2.org) All Rights Reserved.
  ~
  ~ Licensed under the Apache License, Version 2.0 (the "License");
  ~ you may not use this file except in compliance with the License.
  ~ You may obtain a copy of the License at
  ~
  ~      http://www.apache.org/licenses/LICENSE-2.0
  ~
  ~ Unless required by applicable law or agreed to in writing, software
  ~ distributed under the License is distributed on an "AS IS" BASIS,
  ~ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  ~ See the License for the specific language governing permissions and
  ~ limitations under the License.
  -->

<xsl:stylesheet version="1.0"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:syn="http://ws.apache.org/ns/synapse">

    <xsl:template match="syn:proxy">
        <label class="content-header">
            <img src="extensions/core/images/transport-configuration.gif"/>
            <xsl:text> Transport configuration</xsl:text>
        </label>
        <!--<label class="content-description">-->
            <!--Select and configure the transports on which the proxy service should be exposed. The available list of transports-->
            <!--are the transports which are configured for the installation. Transport specific service parameters could be used-->
            <!--to specify JMS destinations etc.-->
        <!--</label>-->
        <br/>
        <br/>
        <xsl:choose>
            <xsl:when test="@a_tp">                
                <table>
                    <tbody>
                        <xsl:call-template name="transport-view">
                            <xsl:with-param name="t_string" select="@a_tp"/>
                        </xsl:call-template>
                    </tbody>
                </table>
            </xsl:when>
            <xsl:otherwise>
                <label style="color: red;">Error in getting transport information</label>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:if test="child::syn:parameter">
            <p>Service Parameters</p><br/>
            <table><thead><th>Name</th><th>Value</th></thead>
                <tbody>
                    <xsl:for-each select="syn:parameter">
                        <xsl:call-template name="view-parameter"/>
                    </xsl:for-each>
                </tbody>
            </table>
        </xsl:if>
    </xsl:template>

    <xsl:template name="transport-view">
        <xsl:param name="t_string"/>

        <xsl:choose>
            <xsl:when test="@transports and @transports != ''">
                <xsl:choose>
                    <xsl:when test="substring-before($t_string, ' ') != ''">
                        <tr>
                            <td style="margin-left: 15px; width:250px; _width:280px; _width:280px;" align="left">
                                <label>
                                    <xsl:value-of
                                            select="translate(substring-before($t_string, ' '), 'abcdefghijklmnopqrstuvwxyz','ABCDEFGHIJKLMNOPQRSTUVWXYZ')"/>
                                </label>
                                <br/>
                            </td>
                            <td style="margin-left: 60px;" align="left">
                                <xsl:choose>
                                    <xsl:when test="contains(concat(@transports, ' '), concat(substring-before($t_string, ' '), ' '))">
                                        <label><img src="extensions/core/images/enabled_icon.png" style="margin-right:10px;" align="absmiddle"/>Enabled</label>
                                    </xsl:when>
                                    <xsl:otherwise>
                                        <label><img src="extensions/core/images/disabled_icon.png" style="margin-right:10px;" align="absmiddle"/>Disabled</label>
                                    </xsl:otherwise>
                                </xsl:choose>
                            </td>
                        </tr>
                        <xsl:call-template name="transport-view">
                            <xsl:with-param name="t_string"
                                            select="substring-after($t_string, ' ')"/>
                        </xsl:call-template>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:if test="$t_string != ''">
                            <tr>
                                <td style="margin-left: 15px; width:250px; _width:280px;" align="left">
                                    <label>
                                        <xsl:value-of
                                                select="translate($t_string, 'abcdefghijklmnopqrstuvwxyz','ABCDEFGHIJKLMNOPQRSTUVWXYZ')"/>
                                    </label>
                                </td>
                                <td style="margin-left: 60px;" align="left">
                                    <xsl:if test="contains(concat(@transports, ' '), concat($t_string, ' '))">
                                        <label><img src="extensions/core/images/enabled_icon.png" style="margin-right:10px;" align="absmiddle"/>Enabled</label>
                                    </xsl:if>
                                </td>
                            </tr>
                        </xsl:if>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:when>
            <xsl:otherwise>
                <xsl:choose>
                    <xsl:when test="substring-before($t_string, ' ') != ''">
                        <tr>
                            <td style="margin-left: 15px; width:250px; _width:280px;" align="left">
                                <label>
                                    <xsl:value-of
                                            select="translate(substring-before($t_string, ' '), 'abcdefghijklmnopqrstuvwxyz','ABCDEFGHIJKLMNOPQRSTUVWXYZ')"/>
                                </label>
                                <br/>
                            </td>
                            <td style="margin-left: 60px;" align="left">
                                <label><img src="extensions/core/images/enabled_icon.png" style="margin-right:10px;" align="absmiddle"/>Enabled</label>
                            </td>
                        </tr>
                        <xsl:call-template name="transport-view">
                            <xsl:with-param name="t_string"
                                            select="substring-after($t_string, ' ')"/>
                        </xsl:call-template>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:if test="$t_string != ''">
                            <tr>
                                <td style="margin-left: 15px; width:250px; _width:280px;" align="left">
                                    <label>
                                        <xsl:value-of
                                                select="translate($t_string, 'abcdefghijklmnopqrstuvwxyz','ABCDEFGHIJKLMNOPQRSTUVWXYZ')"/>
                                    </label>
                                </td>
                                <td style="margin-left: 60px;" align="left">
                                    <label><img src="extensions/core/images/enabled_icon.png" style="margin-right:10px;" align="absmiddle"/>Enabled</label>
                                </td>
                            </tr>
                        </xsl:if>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>

    <xsl:template name="view-parameter">
        <tr>
            <td><xsl:value-of select="@name"/></td>
            <td><xsl:value-of select="."/></td>
        </tr>
    </xsl:template>

</xsl:stylesheet>